(diff-maps old new)(empty-directory! f)(export-page uri pageish target-dir options)(export-pages pages target-dir & [options])(merge-page-sources sources)Merges collections of pages ensuring every path only occurs once across all collections.
Takes a map of collection name to page collection, and returns a map of path to content. The collection names are only used for error reporting.
For example,
(merge-page-sources
{:person-pages (create-person-pages)
:article-pages (create-article-pages)
:general-pages (create-general-pages)})
Merges collections of pages ensuring every path only occurs once across all
collections.
Takes a map of collection name to page collection, and returns a map of path
to content. The collection names are only used for error reporting.
For example,
(merge-page-sources
{:person-pages (create-person-pages)
:article-pages (create-article-pages)
:general-pages (create-general-pages)})(percent-decode encoded)(percent-decode encoded encoding)Decode every percent-encoded character in the given string using the specified encoding, or UTF-8 by default.
Decode every percent-encoded character in the given string using the specified encoding, or UTF-8 by default.
(report-differences old new)(serve-pages get-pages & [options])(slurp-directory dir regexp & opts)Returns a map of paths to file contents in the dir. dir should be
accessible via clojure.java.io/as-file. regexp will be used to filter the
files. opts are passed to slurp to enable specification of encoding and
buffer-size etc.
Returns a map of paths to file contents in the `dir`. `dir` should be accessible via `clojure.java.io/as-file`. `regexp` will be used to filter the files. `opts` are passed to `slurp` to enable specification of encoding and buffer-size etc.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |